==> bitcoin-0.21.1.knots20210629.tar.gz: bitcoin-0.21.1.knots20210629/src/qt/locale/bitcoin_kl.ts <==
<TS language="kl" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nutaamik sanagit</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopeeruk</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>M&amp;atuguk</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Allattorsimaffimminngaanniit toqqakkat peeruk</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Peeruk</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Taaguut</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Isissutissaq allaguk</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Isissutissaq nutaaq sanajuk</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Isissutissaq ilaaqqiguk</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>Isissutissaq nuisiguk</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Aningaasiviit kode-leruk</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Aningaasiviit parnaarunnaaruk</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Aningaasivik kodea peeruk</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Isertaatik allanngortiguk</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Aningaasivippit matuersaataa uppernarsaruk</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Angingaasivik paasipuminaappoq</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Aningaasiviup isissutissaa taarserpoq</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Options...</source>
        <translation type="unfinished">&amp;Toqqagassat...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation type="unfinished">&amp;Aningaasiviit kode-leruk...</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Aningaasivik:</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Nuisiguk / Tarrisiguk</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation>Ammaruk aningaasivik</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Bitcoin amerlassusaa: %1
</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Bitcoin amerlassusaa:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Akileraarut:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Akileraarut peereerlugu:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bitcoin amerlassusaa</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Ulloq</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Akuersissutit</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Akuerineqarpoq</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Aningaasivik</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation>Aningaasiviit kode-leruk</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Taajuut</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Aningaasivik ammarneqanngilaq</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Tikilluarit</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>Tikilluarit uunga %1</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Hide</source>
        <translation>Tarrisiguk</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Toqqagassat</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">&amp;Aningaasivik</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Matuguk</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Aningaasat amerlassusaa</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation>%1 t</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">Aningaasivik: </translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">&amp;Aningaasat amerlassusaa:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Taajuut:</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Aningaasivik ammarneqanngilaq</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Aningaasat amerlassusaa:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">Taajuut:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Aningaasivik:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Ulloq</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Taaguut</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Bitcoin amerlassusaa:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Akileraarut</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Akileraarut peereerlugu:</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Tarrisiguk</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">&amp;Bitcoin amerlassusaa:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Taajuut:</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Ulloq</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Aningaasat amerlassusaa</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Ulloq</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Taaguut</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Confirmed</source>
        <translation>Akuerineqarpoq</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Ulloq</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Taaguut</translation>
    </message>
    </context>
</TS>

==> bitcoin-21.2.knots20210629.tar.gz: bitcoin-21.2.knots20210629/src/qt/locale/bitcoin_kl.ts <==
<TS language="kl" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nutaamik sanagit</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopeeruk</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>M&amp;atuguk</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Allattorsimaffimminngaanniit toqqakkat peeruk</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Peeruk</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Taaguut</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Isissutissaq allaguk</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Isissutissaq nutaaq sanajuk</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Isissutissaq ilaaqqiguk</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>Isissutissaq nuisiguk</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Aningaasiviit kode-leruk</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Aningaasiviit parnaarunnaaruk</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Aningaasivik kodea peeruk</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Isertaatik allanngortiguk</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Aningaasivippit matuersaataa uppernarsaruk</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Angingaasivik paasipuminaappoq</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Aningaasiviup isissutissaa taarserpoq</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Options...</source>
        <translation type="unfinished">&amp;Toqqagassat...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation type="unfinished">&amp;Aningaasiviit kode-leruk...</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Aningaasivik:</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Nuisiguk / Tarrisiguk</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation>Ammaruk aningaasivik</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Bitcoin amerlassusaa: %1
</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Bitcoin amerlassusaa:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Akileraarut:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Akileraarut peereerlugu:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bitcoin amerlassusaa</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Ulloq</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Akuersissutit</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Akuerineqarpoq</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Aningaasivik</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation>Aningaasiviit kode-leruk</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Taajuut</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Aningaasivik ammarneqanngilaq</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Tikilluarit</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>Tikilluarit uunga %1</translation>
    </message>
    </context>
<context>
    <name>MempoolStats</name>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Hide</source>
        <translation>Tarrisiguk</translation>
    </message>
    </context>
<context>
    <name>NetWatchLogModel</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation>Ammaruk aningaasivik</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Toqqagassat</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">&amp;Aningaasivik</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Matuguk</translation>
    </message>
    </context>
<context>
    <name>PairingPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Aningaasat amerlassusaa</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation>%1 t</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">Aningaasivik: </translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">&amp;Aningaasat amerlassusaa:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Taajuut:</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Aningaasivik ammarneqanngilaq</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Aningaasat amerlassusaa:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">Taajuut:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Aningaasivik:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Ulloq</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Taaguut</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Bitcoin amerlassusaa:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Akileraarut</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Akileraarut peereerlugu:</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Tarrisiguk</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">&amp;Bitcoin amerlassusaa:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Taajuut:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Ulloq</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Aningaasat amerlassusaa</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Ulloq</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Taaguut</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Confirmed</source>
        <translation>Akuerineqarpoq</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Ulloq</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Taaguut</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>
